@@ -62,7 +62,6 @@ __all__ = (
     'EventStatus',
     'AppCommandType',
     'AppCommandOptionType',
-    'AppCommandPermissionType',
 )
 
 if TYPE_CHECKING:
@@ -683,12 +682,6 @@ class AppCommandType(Enum):
     message = 3
 
 
-class AppCommandPermissionType(Enum):
-    role = 1
-    user = 2
-    channel = 3
-
-
 def create_unknown_value(cls: Type[E], val: Any) -> E:
     value_cls = cls._enum_value_cls_  # type: ignore # This is narrowed below
     name = f'unknown_{val}'
